package com.qaup.system.mapper;

import java.util.List;
import com.qaup.system.domain.SysVehicleInfo;

/**
 * 车辆信息Mapper接口
 * 
 * @author tellme
 * @date 2025-07-01
 */
public interface SysVehicleInfoMapper 
{
    /**
     * 查询车辆信息
     * 
     * @param vehicleId 车辆信息主键
     * @return 车辆信息
     */
    public SysVehicleInfo selectSysVehicleInfoByVehicleId(Long vehicleId);

    /**
     * 查询车辆信息列表
     * 
     * @param sysVehicleInfo 车辆信息
     * @return 车辆信息集合
     */
    public List<SysVehicleInfo> selectSysVehicleInfoList(SysVehicleInfo sysVehicleInfo);

    /**
     * 新增车辆信息
     * 
     * @param sysVehicleInfo 车辆信息
     * @return 结果
     */
    public int insertSysVehicleInfo(SysVehicleInfo sysVehicleInfo);

    /**
     * 修改车辆信息
     * 
     * @param sysVehicleInfo 车辆信息
     * @return 结果
     */
    public int updateSysVehicleInfo(SysVehicleInfo sysVehicleInfo);

    /**
     * 删除车辆信息
     * 
     * @param vehicleId 车辆信息主键
     * @return 结果
     */
    public int deleteSysVehicleInfoByVehicleId(Long vehicleId);

    /**
     * 批量删除车辆信息
     * 
     * @param vehicleIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysVehicleInfoByVehicleIds(Long[] vehicleIds);

    /**
     * 批量查询车牌号是否存在
     * 
     * @param plateNumbers 车牌号列表
     * @return 存在的车牌号列表
     */
    public List<String> selectExistingLicensePlates(List<String> plateNumbers);
}
